@@ -41,7 +41,6 @@ from . import adapter_ficwadcom
 from . import adapter_fimfictionnet
 from . import adapter_mediaminerorg
 from . import adapter_potionsandsnitches
-from . import adapter_tenhawkpresentscom
 from . import adapter_adastrafanficcom
 from . import adapter_tthfanficorg
 from . import adapter_twilightednet
@@ -90,7 +89,6 @@ from . import adapter_efpfanficnet
 from . import adapter_potterficscom
 from . import adapter_efictionestelielde
 from . import adapter_imagineeficcom
-from . import adapter_asr3slashzoneorg
 from . import adapter_potterheadsanonymouscom
 from . import adapter_fictionpadcom
 from . import adapter_storiesonlinenet
@@ -101,7 +99,6 @@ from . import adapter_spikeluvercom
 from . import adapter_bloodshedversecom
 from . import adapter_fanfichu
 from . import adapter_fictionmaniatv
-from . import adapter_tolkienfanfiction
 from . import adapter_themaplebookshelf
 from . import adapter_fannation
 from . import adapter_sheppardweircom
@@ -121,10 +118,8 @@ from . import adapter_quotevcom
 from . import adapter_mcstoriescom
 from . import adapter_buffygilescom
 from . import adapter_andromedawebcom
-from . import adapter_artemisfowlcom
 from . import adapter_naiceanilmenet
 from . import adapter_deepinmysoulnet
-from . import adapter_kiarepositorymujajinet
 from . import adapter_adultfanfictionorg
 from . import adapter_fictionhuntcom
 from . import adapter_royalroadcom
@@ -161,7 +156,6 @@ from . import adapter_swordborderlineangelcom
 from . import adapter_tasteofpoisoninkubationnet
 from . import adapter_thedelphicexpansecom
 from . import adapter_thundercatsfansorg
-from . import adapter_unknowableroomorg
 from . import adapter_www13hoursorg
 from . import adapter_wwwaneroticstorycom
 from . import adapter_gravitytalescom
@@ -174,6 +168,7 @@ from . import adapter_novelonlinefullcom
 from . import adapter_wwwnovelallcom
 from . import adapter_wuxiaworldco
 from . import adapter_harrypotterfanfictioncom
+from . import adapter_hentaifoundrycom
 
 ## This bit of complexity allows adapters to be added by just adding
 ## importing.  It eliminates the long if/else clauses we used to need
