@@ -100,33 +100,29 @@ class ArchiveOfOurOwnOrgAdapter(BaseSiteAdapter):
 
         params = {}
         if self.password:
-            params['user_session[login]'] = self.username
-            params['user_session[password]'] = self.password
+            params['user[login]'] = self.username
+            params['user[password]'] = self.password
         else:
-            params['user_session[login]'] = self.getConfig("username")
-            params['user_session[password]'] = self.getConfig("password")
-        params['user_session[remember_me]'] = '1'
+            params['user[login]'] = self.getConfig("username")
+            params['user[password]'] = self.getConfig("password")
+        params['user[remember_me]'] = '1'
         params['commit'] = 'Log in'
         params['utf8'] = u'\x2713' # utf8 *is* required now.  hex code works better than actual character for some reason. u'✓'
 
-        # token now comes from meta.
-        # <meta name="csrf-token" content="/Li4mJ1w1AENhQq8EPVIklFwCDP5eaTHNRWPlWkehu2d1iuRzgsOHYGCX+uhjmlKnd1A9VisCdqmeTmBmXZkBg=="/>
-        #params['authenticity_token'] = data.split('meta name="csrf-token" content="')[1].split('"')[0]
         # authenticity_token now comes from a completely separate json call.
         token_json = json.loads(self._fetchUrl('https://' + self.getSiteDomain() + "/token_dispenser.json"))
         params['authenticity_token'] = token_json['token']
 
-        loginUrl = 'https://' + self.getSiteDomain() + '/user_sessions'
+        loginUrl = 'https://' + self.getSiteDomain() + '/users/login'
         logger.info("Will now login to URL (%s) as (%s)" % (loginUrl,
-                                                            params['user_session[login]']))
+                                                            params['user[login]']))
 
         d = self._postUrl(loginUrl, params)
-        #logger.info(d)
 
-        if "Successfully logged in" not in d : #Member Account
+        if 'href="/users/logout"' not in d :
             logger.info("Failed to login to URL %s as %s" % (loginUrl,
-                                                              params['user_session[login]']))
-            raise exceptions.FailedToLogin(url,params['user_session[login]'])
+                                                              params['user[login]']))
+            raise exceptions.FailedToLogin(url,params['user[login]'])
             return False
         else:
             return True
@@ -169,10 +165,7 @@ class ArchiveOfOurOwnOrgAdapter(BaseSiteAdapter):
 
         # need to log in for this one, or always_login.
         if self.needToLoginCheck(data) or \
-                ( self.getConfig("always_login") and 'href="/logout"' not in data ):
-            ## except don't log in if already logged in (cached
-            ## responses in calibre job).  already logged in if
-            ## there's no authenticity_token in data.
+                ( self.getConfig("always_login") and 'href="/users/logout"' not in data ):
             self.performLogin(url,data)
             data = self._fetchUrl(url,usecache=False)
             meta = self._fetchUrl(metaurl,usecache=False)
@@ -192,9 +185,16 @@ class ArchiveOfOurOwnOrgAdapter(BaseSiteAdapter):
         self.story.setMetadata('title',stripHTML(a))
 
         if self.getConfig("always_login"):
+            # deliberately using always_login instead of checking for
+            # actual login so we don't have a case where these show up
+            # for a user only when they get user-restricted stories.
             try:
                 self.story.extendList('bookmarktags',
                                       metasoup.find('input',id='bookmark_tag_string')['value'].split(', '))
+                self.story.setMetadata('bookmarkprivate',
+                                       metasoup.find('input',id='bookmark_private').has_attr('checked'))
+                self.story.setMetadata('bookmarkrec',
+                                       metasoup.find('input',id='bookmark_rec').has_attr('checked'))
             except KeyError:
                 pass
             self.story.setMetadata('bookmarksummary',
