@@ -20,7 +20,7 @@ from __future__ import absolute_import
 import logging
 import re
 # py2 vs py3 transition
-from ..six import text_type as unicode
+from ..six import text_type as unicode, ensure_text
 from ..six.moves.urllib import parse as urlparse
 from ..six.moves.urllib.error import HTTPError
 
@@ -97,14 +97,24 @@ class WuxiaWorldCoSiteAdapter(BaseSiteAdapter):
 
         intro = soup.select_one('#intro')
         # Strip <strong>Description</strong>
-        intro.strong.decompose()
+        if intro.strong:
+            intro.strong.decompose()
         self.setDescription(self.url, intro)
 
-        for a in soup.select('#list a'):
-            url = urlparse.urljoin(self.url, a['href'])
-            title = stripHTML(a)
-            self.add_chapter(title, url)
-
+        dl = soup.select_one('#list > dl')
+        for el in dl.contents:
+            if el.name == u'dt':
+                match = re.match(ensure_text(r'^《.+》\s+(.+)$'), stripHTML(el), re.UNICODE)
+                volume = ''
+                if match and match.group(1) != 'Text':
+                    volume = match.group(1) + ' '
+            elif el.name == u'dd':
+                a = el.a
+                url = urlparse.urljoin(self.url, a['href'])
+                title = volume + stripHTML(a)
+                self.add_chapter(title, url)
+            # else:
+            #     logger.debug('Unexpected tag in #list > dl: %s', el.name)
 
     def getChapterText(self, url):
         logger.debug('Getting chapter text from: %s', url)
